==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkQuadricLODActor.java <==
// java wrapper for vtkQuadricLODActor object
//

package vtk;
import vtk.*;

public class vtkQuadricLODActor extends vtkActor
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDeferLODConstruction_2(int id0);
  public void SetDeferLODConstruction(int id0)
    { SetDeferLODConstruction_2(id0); }

  private native int GetDeferLODConstruction_3();
  public int GetDeferLODConstruction()
    { return GetDeferLODConstruction_3(); }

  private native void DeferLODConstructionOn_4();
  public void DeferLODConstructionOn()
    { DeferLODConstructionOn_4(); }

  private native void DeferLODConstructionOff_5();
  public void DeferLODConstructionOff()
    { DeferLODConstructionOff_5(); }

  private native void SetStatic_6(int id0);
  public void SetStatic(int id0)
    { SetStatic_6(id0); }

  private native int GetStatic_7();
  public int GetStatic()
    { return GetStatic_7(); }

  private native void StaticOn_8();
  public void StaticOn()
    { StaticOn_8(); }

  private native void StaticOff_9();
  public void StaticOff()
    { StaticOff_9(); }

  private native void SetDataConfiguration_10(int id0);
  public void SetDataConfiguration(int id0)
    { SetDataConfiguration_10(id0); }

  private native int GetDataConfigurationMinValue_11();
  public int GetDataConfigurationMinValue()
    { return GetDataConfigurationMinValue_11(); }

  private native int GetDataConfigurationMaxValue_12();
  public int GetDataConfigurationMaxValue()
    { return GetDataConfigurationMaxValue_12(); }

  private native int GetDataConfiguration_13();
  public int GetDataConfiguration()
    { return GetDataConfiguration_13(); }

  private native void SetDataConfigurationToUnknown_14();
  public void SetDataConfigurationToUnknown()
    { SetDataConfigurationToUnknown_14(); }

  private native void SetDataConfigurationToXLine_15();
  public void SetDataConfigurationToXLine()
    { SetDataConfigurationToXLine_15(); }

  private native void SetDataConfigurationToYLine_16();
  public void SetDataConfigurationToYLine()
    { SetDataConfigurationToYLine_16(); }

  private native void SetDataConfigurationToZLine_17();
  public void SetDataConfigurationToZLine()
    { SetDataConfigurationToZLine_17(); }

  private native void SetDataConfigurationToXYPlane_18();
  public void SetDataConfigurationToXYPlane()
    { SetDataConfigurationToXYPlane_18(); }

  private native void SetDataConfigurationToYZPlane_19();
  public void SetDataConfigurationToYZPlane()
    { SetDataConfigurationToYZPlane_19(); }

  private native void SetDataConfigurationToXZPlane_20();
  public void SetDataConfigurationToXZPlane()
    { SetDataConfigurationToXZPlane_20(); }

  private native void SetDataConfigurationToXYZVolume_21();
  public void SetDataConfigurationToXYZVolume()
    { SetDataConfigurationToXYZVolume_21(); }

  private native void SetCollapseDimensionRatio_22(double id0);
  public void SetCollapseDimensionRatio(double id0)
    { SetCollapseDimensionRatio_22(id0); }

  private native double GetCollapseDimensionRatioMinValue_23();
  public double GetCollapseDimensionRatioMinValue()
    { return GetCollapseDimensionRatioMinValue_23(); }

  private native double GetCollapseDimensionRatioMaxValue_24();
  public double GetCollapseDimensionRatioMaxValue()
    { return GetCollapseDimensionRatioMaxValue_24(); }

  private native double GetCollapseDimensionRatio_25();
  public double GetCollapseDimensionRatio()
    { return GetCollapseDimensionRatio_25(); }

  private native void SetLODFilter_26(vtkQuadricClustering id0);
  public void SetLODFilter(vtkQuadricClustering id0)
    { SetLODFilter_26(id0); }

  private native long GetLODFilter_27();
  public vtkQuadricClustering GetLODFilter() {
    long temp = GetLODFilter_27();

    if (temp == 0) return null;
    return (vtkQuadricClustering)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMaximumDisplayListSize_28(int id0);
  public void SetMaximumDisplayListSize(int id0)
    { SetMaximumDisplayListSize_28(id0); }

  private native int GetMaximumDisplayListSizeMinValue_29();
  public int GetMaximumDisplayListSizeMinValue()
    { return GetMaximumDisplayListSizeMinValue_29(); }

  private native int GetMaximumDisplayListSizeMaxValue_30();
  public int GetMaximumDisplayListSizeMaxValue()
    { return GetMaximumDisplayListSizeMaxValue_30(); }

  private native int GetMaximumDisplayListSize_31();
  public int GetMaximumDisplayListSize()
    { return GetMaximumDisplayListSize_31(); }

  private native void SetPropType_32(int id0);
  public void SetPropType(int id0)
    { SetPropType_32(id0); }

  private native int GetPropTypeMinValue_33();
  public int GetPropTypeMinValue()
    { return GetPropTypeMinValue_33(); }

  private native int GetPropTypeMaxValue_34();
  public int GetPropTypeMaxValue()
    { return GetPropTypeMaxValue_34(); }

  private native int GetPropType_35();
  public int GetPropType()
    { return GetPropType_35(); }

  private native void SetPropTypeToFollower_36();
  public void SetPropTypeToFollower()
    { SetPropTypeToFollower_36(); }

  private native void SetPropTypeToActor_37();
  public void SetPropTypeToActor()
    { SetPropTypeToActor_37(); }

  private native void SetCamera_38(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_38(id0); }

  private native long GetCamera_39();
  public vtkCamera GetCamera() {
    long temp = GetCamera_39();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void Render_40(vtkRenderer id0,vtkMapper id1);
  public void Render(vtkRenderer id0,vtkMapper id1)
    { Render_40(id0,id1); }

  private native int RenderOpaqueGeometry_41(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_41(id0); }

  private native void ReleaseGraphicsResources_42(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_42(id0); }

  private native void ShallowCopy_43(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_43(id0); }

  public vtkQuadricLODActor() { super(); }

  public vtkQuadricLODActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-aarch64.pkg.tar.xz: vtk/vtkQuadricLODActor.java <==
// java wrapper for vtkQuadricLODActor object
//

package vtk;
import vtk.*;

public class vtkQuadricLODActor extends vtkActor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDeferLODConstruction_2(int id0);
  public void SetDeferLODConstruction(int id0)
    { SetDeferLODConstruction_2(id0); }

  private native int GetDeferLODConstruction_3();
  public int GetDeferLODConstruction()
    { return GetDeferLODConstruction_3(); }

  private native void DeferLODConstructionOn_4();
  public void DeferLODConstructionOn()
    { DeferLODConstructionOn_4(); }

  private native void DeferLODConstructionOff_5();
  public void DeferLODConstructionOff()
    { DeferLODConstructionOff_5(); }

  private native void SetStatic_6(int id0);
  public void SetStatic(int id0)
    { SetStatic_6(id0); }

  private native int GetStatic_7();
  public int GetStatic()
    { return GetStatic_7(); }

  private native void StaticOn_8();
  public void StaticOn()
    { StaticOn_8(); }

  private native void StaticOff_9();
  public void StaticOff()
    { StaticOff_9(); }

  private native void SetDataConfiguration_10(int id0);
  public void SetDataConfiguration(int id0)
    { SetDataConfiguration_10(id0); }

  private native int GetDataConfigurationMinValue_11();
  public int GetDataConfigurationMinValue()
    { return GetDataConfigurationMinValue_11(); }

  private native int GetDataConfigurationMaxValue_12();
  public int GetDataConfigurationMaxValue()
    { return GetDataConfigurationMaxValue_12(); }

  private native int GetDataConfiguration_13();
  public int GetDataConfiguration()
    { return GetDataConfiguration_13(); }

  private native void SetDataConfigurationToUnknown_14();
  public void SetDataConfigurationToUnknown()
    { SetDataConfigurationToUnknown_14(); }

  private native void SetDataConfigurationToXLine_15();
  public void SetDataConfigurationToXLine()
    { SetDataConfigurationToXLine_15(); }

  private native void SetDataConfigurationToYLine_16();
  public void SetDataConfigurationToYLine()
    { SetDataConfigurationToYLine_16(); }

  private native void SetDataConfigurationToZLine_17();
  public void SetDataConfigurationToZLine()
    { SetDataConfigurationToZLine_17(); }

  private native void SetDataConfigurationToXYPlane_18();
  public void SetDataConfigurationToXYPlane()
    { SetDataConfigurationToXYPlane_18(); }

  private native void SetDataConfigurationToYZPlane_19();
  public void SetDataConfigurationToYZPlane()
    { SetDataConfigurationToYZPlane_19(); }

  private native void SetDataConfigurationToXZPlane_20();
  public void SetDataConfigurationToXZPlane()
    { SetDataConfigurationToXZPlane_20(); }

  private native void SetDataConfigurationToXYZVolume_21();
  public void SetDataConfigurationToXYZVolume()
    { SetDataConfigurationToXYZVolume_21(); }

  private native void SetCollapseDimensionRatio_22(double id0);
  public void SetCollapseDimensionRatio(double id0)
    { SetCollapseDimensionRatio_22(id0); }

  private native double GetCollapseDimensionRatioMinValue_23();
  public double GetCollapseDimensionRatioMinValue()
    { return GetCollapseDimensionRatioMinValue_23(); }

  private native double GetCollapseDimensionRatioMaxValue_24();
  public double GetCollapseDimensionRatioMaxValue()
    { return GetCollapseDimensionRatioMaxValue_24(); }

  private native double GetCollapseDimensionRatio_25();
  public double GetCollapseDimensionRatio()
    { return GetCollapseDimensionRatio_25(); }

  private native void SetLODFilter_26(vtkQuadricClustering id0);
  public void SetLODFilter(vtkQuadricClustering id0)
    { SetLODFilter_26(id0); }

  private native long GetLODFilter_27();
  public vtkQuadricClustering GetLODFilter() {
    long temp = GetLODFilter_27();

    if (temp == 0) return null;
    return (vtkQuadricClustering)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPropType_28(int id0);
  public void SetPropType(int id0)
    { SetPropType_28(id0); }

  private native int GetPropTypeMinValue_29();
  public int GetPropTypeMinValue()
    { return GetPropTypeMinValue_29(); }

  private native int GetPropTypeMaxValue_30();
  public int GetPropTypeMaxValue()
    { return GetPropTypeMaxValue_30(); }

  private native int GetPropType_31();
  public int GetPropType()
    { return GetPropType_31(); }

  private native void SetPropTypeToFollower_32();
  public void SetPropTypeToFollower()
    { SetPropTypeToFollower_32(); }

  private native void SetPropTypeToActor_33();
  public void SetPropTypeToActor()
    { SetPropTypeToActor_33(); }

  private native void SetCamera_34(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_34(id0); }

  private native long GetCamera_35();
  public vtkCamera GetCamera() {
    long temp = GetCamera_35();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Render_36(vtkRenderer id0,vtkMapper id1);
  public void Render(vtkRenderer id0,vtkMapper id1)
    { Render_36(id0,id1); }

  private native int RenderOpaqueGeometry_37(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_37(id0); }

  private native void ReleaseGraphicsResources_38(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_38(id0); }

  private native void ShallowCopy_39(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_39(id0); }

  public vtkQuadricLODActor() { super(); }

  public vtkQuadricLODActor(long id) { super(id); }
  public native long   VTKInit();

}
